Struct InterCall
pub struct InterCall(/* private fields */);Expand description
Used by the callee to end the call with a result.
Implementations
impl InterCall
impl InterCall
pub fn new() -> (Self, Receiver<Vec<u8>>)
pub fn is_pending(&self) -> bool
pub fn is_pending(&self) -> bool
Returns true when this call was created for an inter-lyquid call and still has a
waiting caller.
pub fn set_result(&mut self, data: Vec<u8>)